@@ -170,7 +170,7 @@ fishtree_taxonomy <- function(ranks = NULL) {
 #' }
 fishtree_alignment <- function(species, rank, split = FALSE) {
   if (!rlang::is_missing(species) && !rlang::is_missing(rank))
-    rlang::warn("Supplying both `species` and `rank` arguments may limit the number of results you see")
+    rlang::inform("Supplying both `species` and `rank` arguments may limit the number of results you see.")
 
   if (rlang::is_missing(rank)) {
     url <- "https://fishtreeoflife.org/downloads/final_alignment.phylip.xz"
@@ -186,7 +186,10 @@ fishtree_alignment <- function(species, rank, split = FALSE) {
   }
 
   dna <- .get(url, ape::read.dna, format = "sequential", nlines = nlines)
-  if (!rlang::is_missing(species)) dna <- dna[.name_check(species), ]
+  if (!rlang::is_missing(species)) {
+    valid_names <- .name_check(species)
+    dna <- dna[gsub(" ", "_", valid_names), ]
+  }
   if (split) dna <- .split_seqs(dna)
   dna
 }
@@ -195,7 +198,8 @@ fishtree_alignment <- function(species, rank, split = FALSE) {
 #'
 #' Downloads tip rates for the entire Fish Tree of Life, or for a specified subset. Tip rates can be thought of as an
 #' instantaneous speciation or extinction rate; for example, a higher tip-specific speciation rate might imply that
-#' a lineage is more likely to split a new lineage at the present time. If neither `species` nor `rank` are specified, returns the entire set of tip-specific diversification rates.
+#' a lineage is more likely to split a new lineage at the present time. See Title (2019) in references for details.
+#' If neither `species` nor `rank` are specified, returns the entire set of tip-specific diversification rates.
 #'
 #' @inheritParams fishtree_phylogeny
 #' @param sampled_only Restricts the returned dataset to only those species that have genetic data available. Defaults to `TRUE`.
@@ -204,6 +208,8 @@ fishtree_alignment <- function(species, rank, split = FALSE) {
 #' @references
 #' DR rates (supplement, section 1.2.2): Jetz, W., Thomas, G. H., Joy, J. B., Hartmann, K., & Mooers, A. O. (2012). The global diversity of birds in space and time. Nature, 491(7424), 444–448. doi:10.1038/nature11631
 #'
+#' Interpreting tip rates: Title, P. O., & Rabosky, D. L. (2019). Tip rates, phylogenies and diversification: What are we estimating, and how good are the estimates? Methods in Ecology and Evolution, 10(6), 821–834. doi:10.1111/2041-210x.13153
+#'
 #' BAMM rates: Rabosky, D. L. (2014). Automatic Detection of Key Innovations, Rate Shifts, and Diversity-Dependence on Phylogenetic Trees. PLoS ONE, 9(2), e89543. doi:10.1371/journal.pone.0089543
 #'
 #' Rabosky, D. L., Chang, J., Title, P. O., Cowman, P. F., Sallan, L., Friedman, M., Kashner, K., Garilao, C., Near, T. J., Coll, M., Alfaro, M. E. (2018). An inverse latitudinal gradient in speciation rate for marine fishes. Nature, 559(7714), 392–395. doi:10.1038/s41586-018-0273-1
@@ -268,13 +274,15 @@ fishtree_tip_rates <- function(species, rank, sampled_only = TRUE) {
 
 #' Get complete (stochastically-resolved) phylogenies from the Fish Tree of Life
 #'
-#' Retrieves a complete, stochastically-resolved phylogeny via the Fish Tree of Life API. If neither `species` nor `rank` are specified, returns the entire phylogeny.
+#' Retrieves a complete, stochastically-resolved phylogeny via the Fish Tree of Life API. If neither `species` nor `rank` are specified, returns the entire phylogeny. WARNING: These phylogenies should generally not be used for downstream analyses of trait evolution. See Rabosky (2015) in the references for details.
 #'
 #' @inheritParams fishtree_phylogeny
 #' @param mc.cores Number of cores to use in \link[parallel]{mclapply} when subsetting the tree (default `1`)
-#' @return An object of class `"multiPhylo"`.
+#' @return An object of class `"multiPhylo"` that should probably not be used for analyses of trait evolution, including (but not limited to) \link[ape]{pic}, \link[ape]{ace}, \link[ape]{corBrownian}, \link[diversitree]{make.bisse}, or \link[hisse]{hisse}.
 #' @export
 #' @references
+#' Rabosky, D. L. (2015). No substitute for real data: A cautionary note on the use of phylogenies from birth-death polytomy resolvers for downstream comparative analyses. Evolution, 69(12), 3207–3216. doi:10.1111/evo.12817
+#'
 #' Rabosky, D. L., Chang, J., Title, P. O., Cowman, P. F., Sallan, L., Friedman, M., Kashner, K., Garilao, C., Near, T. J., Coll, M., Alfaro, M. E. (2018). An inverse latitudinal gradient in speciation rate for marine fishes. Nature, 559(7714), 392–395. doi:10.1038/s41586-018-0273-1
 #'
 #' Enhanced polytomy resolution strengthens evidence for global gradient in speciation rate for marine fishes. \url{https://fishtreeoflife.org/rabosky-et-al-2018-update/}
